@@ -132,7 +132,6 @@ pub fn functions() -> HashSet<&'static str>
         "mat",
         "prime",
         "reverse",
-        "link",
         "flatten",
         "I",
         "P",
@@ -274,6 +273,23 @@ pub fn functions() -> HashSet<&'static str>
         "rand_neg_hypergeometric",
         "cyl",
         "cylinder",
+        "prime_factors",
+        "hsv_to_rgb",
+        "domain_coloring_rgb",
+        "set",
+        "uniq",
+        "union",
+        "intersection",
+        "set_difference",
+        "symmetric_difference",
+        "cartesian_product",
+        "power_set",
+        "set_fix",
+        "subset",
+        "element",
+        "remove",
+        "extend",
+        "link",
     ]
     .iter()
     .cloned()
@@ -378,7 +394,6 @@ pub fn functions_with_args() -> HashSet<&'static str>
         "eigenvectors(mat)",
         "mat(a,f(a),start,end)",
         "reverse(vec)",
-        "link(vec,vec)",
         "flatten(mat)",
         "I(x,α,β(,z))",
         "P(n,r)",
@@ -447,7 +462,7 @@ pub fn functions_with_args() -> HashSet<&'static str>
         "surfacearea(a,b,z(a,b),start_b,end_b,start_a,end_a)",
         "covariance(vec)",
         "extrema(a,f(a)(,start))",
-        "plane(mat(,x,y)",
+        "plane(mat(,x,y))",
         "is_nan(x)",
         "is_inf(x)",
         "is_finite(x)",
@@ -457,7 +472,7 @@ pub fn functions_with_args() -> HashSet<&'static str>
         "rand_uniform(a,b)",
         "geo_mean(vec)",
         "γ(s(,x))",
-        "lower_gamma(s(,x))",
+        "lower_gamma(s,x)",
         "gamma_pdf(k,θ)",
         "gamma_cdf(k,θ)",
         "rand_gamma(k,θ)",
@@ -487,6 +502,22 @@ pub fn functions_with_args() -> HashSet<&'static str>
         "neg_hypergeometric_cdf(k,N,K,r)",
         "rand_neg_hypergeometric(N,K,r)",
         "cylinder({x,y,z})",
+        "prime_factors(n)",
+        "hsv_to_rgb({h,s,v})",
+        "domain_coloring_rgb(x)",
+        "set(a,f(a),val)",
+        "uniq({vec})",
+        "union(A,B)",
+        "intersection(A,B)",
+        "set_difference(A,B)",
+        "symmetric_difference(A,B)",
+        "cartesian_product(A,B)",
+        "power_set(A)",
+        "set_fix(A)",
+        "subset(A,B)",
+        "element(A,b)",
+        "remove(vec,num/vec)",
+        "extend(vec,num/vec)",
     ]
     .iter()
     .cloned()
@@ -495,6 +526,20 @@ pub fn functions_with_args() -> HashSet<&'static str>
 pub fn units_list() -> HashSet<&'static str>
 {
     [
+        "eV",
+        "eC",
+        "eM",
+        "pM",
+        "nM",
+        "ke",
+        "Na",
+        "R",
+        "boltzmann",
+        "gravity",
+        "G",
+        "planck",
+        "reduced_planck",
+        "c",
         "meter",
         "second",
         "ampere",
@@ -561,6 +606,152 @@ pub fn units_list() -> HashSet<&'static str>
         "parsec",
         "au",
         "floz",
+        "AUD",
+        "CAD",
+        "CNY",
+        "EUR",
+        "GBP",
+        "HKD",
+        "IDR",
+        "INR",
+        "JPY",
+        "KRW",
+        "MYR",
+        "NZD",
+        "PHP",
+        "SGD",
+        "THB",
+        "TWD",
+        "VND",
+        "BGN",
+        "BRL",
+        "CHF",
+        "CLP",
+        "CZK",
+        "DKK",
+        "HUF",
+        "ILS",
+        "ISK",
+        "MXN",
+        "NOK",
+        "PLN",
+        "RON",
+        "SEK",
+        "TRY",
+        "UAH",
+        "ZAR",
+        "EGP",
+        "JOD",
+        "LBP",
+        "AED",
+        "MDL",
+        "RSD",
+        "RUB",
+        "AMD",
+        "AZN",
+        "BDT",
+        "DOP",
+        "DZD",
+        "GEL",
+        "IQD",
+        "IRR",
+        "KGS",
+        "KZT",
+        "LYD",
+        "MAD",
+        "PKR",
+        "SAR",
+        "TJS",
+        "TMT",
+        "TND",
+        "UZS",
+        "XAF",
+        "XOF",
+        "BYN",
+        "PEN",
+        "VES",
+        "ARS",
+        "BOB",
+        "COP",
+        "CRC",
+        "HTG",
+        "PAB",
+        "PYG",
+        "UYU",
+        "NGN",
+        "AFN",
+        "ALL",
+        "ANG",
+        "AOA",
+        "AWG",
+        "BAM",
+        "BBD",
+        "BHD",
+        "BIF",
+        "BND",
+        "BSD",
+        "BWP",
+        "BZD",
+        "CDF",
+        "CUP",
+        "CVE",
+        "DJF",
+        "ERN",
+        "ETB",
+        "FJD",
+        "GHS",
+        "GIP",
+        "GMD",
+        "GNF",
+        "GTQ",
+        "GYD",
+        "HNL",
+        "JMD",
+        "KES",
+        "KHR",
+        "KMF",
+        "KWD",
+        "LAK",
+        "LKR",
+        "LRD",
+        "LSL",
+        "MGA",
+        "MKD",
+        "MMK",
+        "MNT",
+        "MOP",
+        "MRU",
+        "MUR",
+        "MVR",
+        "MWK",
+        "MZN",
+        "NAD",
+        "NIO",
+        "NPR",
+        "OMR",
+        "PGK",
+        "QAR",
+        "RWF",
+        "SBD",
+        "SCR",
+        "SDG",
+        "SOS",
+        "SRD",
+        "SSP",
+        "STN",
+        "SVC",
+        "SYP",
+        "SZL",
+        "TOP",
+        "TTD",
+        "TZS",
+        "UGX",
+        "VUV",
+        "WST",
+        "XCD",
+        "XPF",
+        "YER",
+        "ZMW",
     ]
     .iter()
     .cloned()
@@ -573,6 +764,7 @@ pub fn options_list() -> HashSet<&'static str>
         "slowcheck=",
         "interactive=",
         "prompt=",
+        "progress=",
         "surface=",
         "rt=",
         "siunits=",
@@ -614,8 +806,8 @@ pub fn options_list() -> HashSet<&'static str>
         "notation=",
         "graph=",
         "saveto=",
-        "re1col=",
-        "im1col=",
+        "recol=",
+        "imcol=",
         "textc=",
         "promptc=",
         "imagc=",
@@ -624,6 +816,7 @@ pub fn options_list() -> HashSet<&'static str>
         "bracketc=",
         "label=",
         "point=",
+        "default_units=",
     ]
     .iter()
     .cloned()
